
# letterboxd

![Redlettermedia example](https://i.imgur.com/34XaBY0.png)

python3 movies.py

Arguments

  `--user USER` `-u USER`   letterboxd.com user

  `--reviews` `-r`          Gets reviews

  `--testing` `-t`          Testing flag - for development only

  `--save-json` `-j`        Saves a JSON file of the reviews dictionary

  `--save-html` `-w`          Saves an HTML document for easily viewing reviews

  `--browser-open` `-b`        Opens saved HTML document in the browser

  `--search SEARCH [SEARCH ...]` `-s SEARCH [SEARCH ...]`
